#ifndef EXTRAN_H
#define EXTRAN_H

#define EXTRAN_TIM 1
#define EXTRAN_SYI 2
#define EXTRAN_DVI_SYS 4
#define EXTRAN_DVI_USR 8
#define EXTRAN_JPI 16
#define EXTRAN_CNT 32
#define EXTRAN_HSH 64

/*
 * get_extran_data
 *
 * arguments:
 *     buf - pointer to char array that will receive 32 random bytes with SHA-256 of source data
 *     flags - mask of sources to use
 *                 EXTRAN_TIM 8 bytes from SYS$GETTIM (not unpredictable)
 *                 EXTRAN_SYI 112 bytes from SYS$GETSYIW
 *                 EXTRAN_DVI_SYS 64 bytes from SYS$GETDVIW on SYS$SYSDEVIVE
 *                 EXTRAN_DVI_USR 64 bytes from SYS$GETDVIW on SYS$DISK
 *                 EXTRAN_JPI 520 bytes from SYS$GETJPIW
 *                 EXTRAN_CNT 40 bytes from an array of counters (not unpredictable but ensures change with multiple calls)
 *                 EXTRAN_HSH 32 bytes of SHA-256 of all other data (not unpredictable but may make reversing more difficult)
 *
 * return value:
 *     SS$_NORMAL - 32 random bytes generated
 *     SS$_BADPARAM - non valid flags resulting in no random bytes generated
 *
 */
long int get_extran_data(char *buf, long int flag);

#endif
